==> chromium-92.0.4515.92.tar.xz: chromium-92.0.4515.92/chrome/browser/ui/ash/wallpaper_controller_client_impl.h <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_ASH_WALLPAPER_CONTROLLER_CLIENT_IMPL_H_
#define CHROME_BROWSER_UI_ASH_WALLPAPER_CONTROLLER_CLIENT_IMPL_H_

#include <memory>

#include "ash/public/cpp/wallpaper_controller.h"
#include "ash/public/cpp/wallpaper_controller_client.h"
#include "ash/public/cpp/wallpaper_types.h"
#include "base/macros.h"
#include "chrome/browser/ash/settings/cros_settings.h"
#include "components/prefs/pref_change_registrar.h"
#include "url/gurl.h"

class AccountId;
class ValueStore;

namespace base {
class SequencedTaskRunner;
}  // namespace base

// Handles chrome-side wallpaper control alongside the ash-side controller.
class WallpaperControllerClientImpl : public ash::WallpaperControllerClient {
 public:
  WallpaperControllerClientImpl();
  virtual ~WallpaperControllerClientImpl();

  // Initializes and connects to ash.
  void Init();

  // Tests can provide a mock interface for the ash controller.
  void InitForTesting(ash::WallpaperController* controller);

  // Sets the initial wallpaper. Should be called after the session manager has
  // been initialized.
  void SetInitialWallpaper();

  static WallpaperControllerClientImpl* Get();

  // Returns a suffix to be appended to the base url of Backdrop (online)
  // wallpapers.
  static std::string GetBackdropWallpaperSuffix();

  // Returns files identifier for the |account_id|.
  std::string GetFilesId(const AccountId& account_id) const;

  // ash::WallpaperControllerClient:
  void OpenWallpaperPicker() override;
  void MaybeClosePreviewWallpaper() override;
  void SetDefaultWallpaper(const AccountId& account_id,
                           bool show_wallpaper) override;
  void MigrateCollectionIdFromChromeApp() override;

  // Wrappers around the ash::WallpaperController interface.
  void SetCustomWallpaper(const AccountId& account_id,
                          const std::string& wallpaper_files_id,
                          const std::string& file_name,
                          ash::WallpaperLayout layout,
                          const gfx::ImageSkia& image,
                          bool preview_mode);
  void SetOnlineWallpaper(
      const AccountId& account_id,
      const GURL& url,
      ash::WallpaperLayout layout,
      bool preview_mode,
      ash::WallpaperController::SetOnlineWallpaperCallback callback);
  void SetOnlineWallpaperIfExists(
      const AccountId& account_id,
      const std::string& url,
      ash::WallpaperLayout layout,
      bool preview_mode,
      ash::WallpaperController::SetOnlineWallpaperCallback callback);
  void SetOnlineWallpaperFromData(
      const AccountId& account_id,
      const std::string& image_data,
      const std::string& url,
      ash::WallpaperLayout layout,
      bool preview_mode,
      ash::WallpaperController::SetOnlineWallpaperCallback callback);
  void SetCustomizedDefaultWallpaperPaths(
      const base::FilePath& customized_default_small_path,
      const base::FilePath& customized_default_large_path);
  void SetPolicyWallpaper(const AccountId& account_id,
                          std::unique_ptr<std::string> data);
  bool SetThirdPartyWallpaper(const AccountId& account_id,
                              const std::string& wallpaper_files_id,
                              const std::string& file_name,
                              ash::WallpaperLayout layout,
                              const gfx::ImageSkia& image);
  void ConfirmPreviewWallpaper();
  void CancelPreviewWallpaper();
  void UpdateCustomWallpaperLayout(const AccountId& account_id,
                                   ash::WallpaperLayout layout);
  void ShowUserWallpaper(const AccountId& account_id);
  void ShowSigninWallpaper();
  void ShowAlwaysOnTopWallpaper(const base::FilePath& image_path);
  void RemoveAlwaysOnTopWallpaper();
  void RemoveUserWallpaper(const AccountId& account_id);
  void RemovePolicyWallpaper(const AccountId& account_id);
  void GetOfflineWallpaperList(
      ash::WallpaperController::GetOfflineWallpaperListCallback callback);
  void SetAnimationDuration(const base::TimeDelta& animation_duration);
  void OpenWallpaperPickerIfAllowed();
  void MinimizeInactiveWindows(const std::string& user_id_hash);
  void RestoreMinimizedWindows(const std::string& user_id_hash);
  void AddObserver(ash::WallpaperControllerObserver* observer);
  void RemoveObserver(ash::WallpaperControllerObserver* observer);
  gfx::ImageSkia GetWallpaperImage();
  const std::vector<SkColor>& GetWallpaperColors();
  bool IsWallpaperBlurred();
  bool IsActiveUserWallpaperControlledByPolicy();
  ash::WallpaperInfo GetActiveUserWallpaperInfo();
  bool ShouldShowWallpaperSetting();
  void MigrateCollectionIdFromValueStoreForTesting(ValueStore* storage);

 private:
  // Initialize the controller for this client and some wallpaper directories.
  void InitController();

  // Shows the wallpaper of the first user in |UserManager::GetUsers|, or a
  // default signin wallpaper if there's no user. This ensures the wallpaper is
  // shown right after boot, regardless of when the login screen is available.
  void ShowWallpaperOnLoginScreen();

  void DeviceWallpaperImageFilePathChanged();

  // Returns true if user names should be shown on the login screen.
  bool ShouldShowUserNamesOnLogin() const;

  base::FilePath GetDeviceWallpaperImageFilePath();

  // Used as callback to |MigrateCollectionIdFromChromeApp|. Called on backend
  // task runner. Extracts the daily refresh collection id and calls
  // |SetDailyRefreshCollectionId| on main task runner.
  void OnGetWallpaperChromeAppValueStore(
      scoped_refptr<base::SequencedTaskRunner> main_task_runner,
      ValueStore* value_store);

  // Passes |collection_id| to wallpaper controller on main task runner.
  void SetDailyRefreshCollectionId(const std::string& collection_id);

  // WallpaperController interface in ash.
  ash::WallpaperController* wallpaper_controller_;

  PrefService* local_state_;

  // The registrar used to watch DeviceWallpaperImageFilePath pref changes.
  PrefChangeRegistrar pref_registrar_;

  // Subscription for a callback that monitors if user names should be shown on
  // the login screen, which determines whether a user wallpaper or a default
  // wallpaper should be shown.
  base::CallbackListSubscription show_user_names_on_signin_subscription_;

  base::WeakPtrFactory<WallpaperControllerClientImpl> weak_factory_{this};
  base::WeakPtrFactory<WallpaperControllerClientImpl> storage_weak_factory_{
      this};

  DISALLOW_COPY_AND_ASSIGN(WallpaperControllerClientImpl);
};

#endif  // CHROME_BROWSER_UI_ASH_WALLPAPER_CONTROLLER_CLIENT_IMPL_H_

==> chromium-93.0.4549.3.tar.xz: chromium-93.0.4549.3/chrome/browser/ui/ash/wallpaper_controller_client_impl.h <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_ASH_WALLPAPER_CONTROLLER_CLIENT_IMPL_H_
#define CHROME_BROWSER_UI_ASH_WALLPAPER_CONTROLLER_CLIENT_IMPL_H_

#include <memory>

#include "ash/public/cpp/wallpaper_controller.h"
#include "ash/public/cpp/wallpaper_controller_client.h"
#include "ash/public/cpp/wallpaper_types.h"
#include "base/macros.h"
#include "chrome/browser/ash/backdrop_wallpaper_handlers/backdrop_wallpaper_handlers.h"
#include "chrome/browser/ash/settings/cros_settings.h"
#include "components/prefs/pref_change_registrar.h"
#include "url/gurl.h"

class AccountId;
class ValueStore;

namespace base {
class SequencedTaskRunner;
}  // namespace base

// Handles chrome-side wallpaper control alongside the ash-side controller.
class WallpaperControllerClientImpl : public ash::WallpaperControllerClient {
 public:
  WallpaperControllerClientImpl();
  virtual ~WallpaperControllerClientImpl();

  // Initializes and connects to ash.
  void Init();

  // Tests can provide a mock interface for the ash controller.
  void InitForTesting(ash::WallpaperController* controller);

  // Sets the initial wallpaper. Should be called after the session manager has
  // been initialized.
  void SetInitialWallpaper();

  static WallpaperControllerClientImpl* Get();

  // Returns files identifier for the |account_id|.
  std::string GetFilesId(const AccountId& account_id) const;

  // ash::WallpaperControllerClient:
  void OpenWallpaperPicker() override;
  void MaybeClosePreviewWallpaper() override;
  void SetDefaultWallpaper(const AccountId& account_id,
                           bool show_wallpaper) override;
  void MigrateCollectionIdFromChromeApp() override;
  void FetchDailyRefreshWallpaper(
      const std::string& collection_id,
      DailyWallpaperUrlFetchedCallback callback) override;
  void SaveWallpaperToDriveFs(const AccountId& account_id,
                              const base::FilePath& origin) override;

  // Wrappers around the ash::WallpaperController interface.
  void SetCustomWallpaper(const AccountId& account_id,
                          const std::string& wallpaper_files_id,
                          const std::string& file_name,
                          ash::WallpaperLayout layout,
                          const gfx::ImageSkia& image,
                          bool preview_mode);
  void SetOnlineWallpaper(
      const AccountId& account_id,
      const absl::optional<uint64_t>& asset_id,
      const GURL& url,
      const std::string& collection_id,
      ash::WallpaperLayout layout,
      bool preview_mode,
      ash::WallpaperController::SetOnlineWallpaperCallback callback);
  void SetOnlineWallpaperIfExists(
      const AccountId& account_id,
      const absl::optional<uint64_t>& asset_id,
      const std::string& url,
      const std::string& collection_id,
      ash::WallpaperLayout layout,
      bool preview_mode,
      ash::WallpaperController::SetOnlineWallpaperCallback callback);
  void SetOnlineWallpaperFromData(
      const AccountId& account_id,
      const std::string& image_data,
      const std::string& url,
      ash::WallpaperLayout layout,
      bool preview_mode,
      ash::WallpaperController::SetOnlineWallpaperCallback callback);
  void SetCustomizedDefaultWallpaperPaths(
      const base::FilePath& customized_default_small_path,
      const base::FilePath& customized_default_large_path);
  void SetPolicyWallpaper(const AccountId& account_id,
                          std::unique_ptr<std::string> data);
  bool SetThirdPartyWallpaper(const AccountId& account_id,
                              const std::string& wallpaper_files_id,
                              const std::string& file_name,
                              ash::WallpaperLayout layout,
                              const gfx::ImageSkia& image);
  void ConfirmPreviewWallpaper();
  void CancelPreviewWallpaper();
  void UpdateCustomWallpaperLayout(const AccountId& account_id,
                                   ash::WallpaperLayout layout);
  void ShowUserWallpaper(const AccountId& account_id);
  void ShowSigninWallpaper();
  void ShowAlwaysOnTopWallpaper(const base::FilePath& image_path);
  void RemoveAlwaysOnTopWallpaper();
  void RemoveUserWallpaper(const AccountId& account_id);
  void RemovePolicyWallpaper(const AccountId& account_id);
  void GetOfflineWallpaperList(
      ash::WallpaperController::GetOfflineWallpaperListCallback callback);
  void SetAnimationDuration(const base::TimeDelta& animation_duration);
  void OpenWallpaperPickerIfAllowed();
  void MinimizeInactiveWindows(const std::string& user_id_hash);
  void RestoreMinimizedWindows(const std::string& user_id_hash);
  void AddObserver(ash::WallpaperControllerObserver* observer);
  void RemoveObserver(ash::WallpaperControllerObserver* observer);
  gfx::ImageSkia GetWallpaperImage();
  const std::vector<SkColor>& GetWallpaperColors();
  bool IsWallpaperBlurred();
  bool IsActiveUserWallpaperControlledByPolicy();
  ash::WallpaperInfo GetActiveUserWallpaperInfo();
  bool ShouldShowWallpaperSetting();
  void MigrateCollectionIdFromValueStoreForTesting(ValueStore* storage);

 private:
  // Initialize the controller for this client and some wallpaper directories.
  void InitController();

  // Shows the wallpaper of the first user in |UserManager::GetUsers|, or a
  // default signin wallpaper if there's no user. This ensures the wallpaper is
  // shown right after boot, regardless of when the login screen is available.
  void ShowWallpaperOnLoginScreen();

  void DeviceWallpaperImageFilePathChanged();

  // Returns true if user names should be shown on the login screen.
  bool ShouldShowUserNamesOnLogin() const;

  base::FilePath GetDeviceWallpaperImageFilePath();

  // Used as callback to |MigrateCollectionIdFromChromeApp|. Called on backend
  // task runner. Extracts the daily refresh collection id and calls
  // |SetDailyRefreshCollectionId| on main task runner.
  void OnGetWallpaperChromeAppValueStore(
      scoped_refptr<base::SequencedTaskRunner> main_task_runner,
      ValueStore* value_store);

  // Passes |collection_id| to wallpaper controller on main task runner.
  void SetDailyRefreshCollectionId(const std::string& collection_id);

  void OnDailyImageInfoFetched(DailyWallpaperUrlFetchedCallback callback,
                               bool success,
                               const backdrop::Image& image,
                               const std::string& next_resume_token);

  // WallpaperController interface in ash.
  ash::WallpaperController* wallpaper_controller_;

  PrefService* local_state_;

  // The registrar used to watch DeviceWallpaperImageFilePath pref changes.
  PrefChangeRegistrar pref_registrar_;

  // Subscription for a callback that monitors if user names should be shown on
  // the login screen, which determines whether a user wallpaper or a default
  // wallpaper should be shown.
  base::CallbackListSubscription show_user_names_on_signin_subscription_;

  std::unique_ptr<backdrop_wallpaper_handlers::SurpriseMeImageFetcher>
      surprise_me_image_fetcher_;

  base::WeakPtrFactory<WallpaperControllerClientImpl> weak_factory_{this};
  base::WeakPtrFactory<WallpaperControllerClientImpl> storage_weak_factory_{
      this};

  DISALLOW_COPY_AND_ASSIGN(WallpaperControllerClientImpl);
};

#endif  // CHROME_BROWSER_UI_ASH_WALLPAPER_CONTROLLER_CLIENT_IMPL_H_
